@@ -2,6 +2,10 @@
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 
+try:
+    from libs.modelmixins import UrlMixin
+except ImportError:
+    from cryotec_server.libs.modelmixins import UrlMixin
 try:
     from django.db import models
 except ImportError:
@@ -45,4 +49,4 @@ class Upload(models.Model):
     
     
     def __unicode__(self):
-        return "%s" % self.file.name
\ No newline at end of file
+        return "%s" % self.file.name
