@@ -1,4 +1,4 @@
-
+# -*- coding: utf-8 -*-
 
 
 def django_root_url(fq=False):
@@ -29,4 +29,15 @@ def current_site_url():
     url = '%s://%s' % (protocol, current_site.domain)
     if port:
         url += ':%s' % port
-    return url
\ No newline at end of file
+    return url
+
+
+def humanize_value(value):
+    if value == 'None':
+        return u"пусто"
+    elif value=='False':
+        return u"нет"
+    elif value=='True':
+        return u"да"
+    else:
+        return value
\ No newline at end of file
